@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Read.pm 1827 2009-04-08 15:24:43Z hikarin $
+# $Id: Read.pm 1869 2009-10-18 12:06:24Z hikarin $
 #
 
 package Img0ch::App::Read;
@@ -134,6 +134,7 @@ sub load_thread {
     my $count             = $iApp->{__thread_count};
     my $loop              = int( $count / 100 ) + 1;
     my $omit              = $option->{noname};
+    my $br2nl             = $option->{br2nl};
     my $noname            = $iSetting->get('BBS_NONAME_NAME');
 
     my $st        = $iApp->{__read_from};
@@ -165,6 +166,7 @@ sub load_thread {
         my $textnt;
         if ($mobile) {
             ( $omit and $name eq $noname ) and $name = '';
+            $br2nl and $name =~ s{</?b>}{}gxms;
             $textnt = $text;
             $textnt =~ s{<br\s*/?>}{\t}gxms;
             $textnt =~ s{<[^>]+>}{}gxms;
@@ -195,6 +197,7 @@ sub load_thread {
         my $textnt;
         if ($mobile) {
             ( $omit and $name eq $noname ) and $name = '';
+            $br2nl and $name =~ s{</?b>}{}gxms;
             $textnt = $text;
             $textnt =~ s{<br\s*/?>}{\t}gxms;
             $textnt =~ s{<[^>]+>}{}gxms;
@@ -291,8 +294,9 @@ sub load_thread {
         return $template_parameters;
     }
     else {
+        my $cs = $iBBS->get_encoding();
         $iTemplate->param($template_parameters);
-        $iRequest->send_http_header('text/html');
+        $iRequest->send_http_header( 'text/html', $cs );
         $iTemplate->flush( $option->{filter} );
         return 1;
     }
