@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: VTA.pm 1827 2009-04-08 15:24:43Z hikarin $
+# $Id: VTA.pm 1826 2009-04-08 15:23:25Z hikarin $
 #
 
 package Img0ch::App::VTA;
@@ -57,7 +57,8 @@ sub run {
     }
 
     $result or return $iApp->redirect_error('remove');
-    $iRequest->send_http_header( $ctype || 'text/html' );
+    my $cs = $iApp->{__bbs} ? $iApp->{__bbs}->get_encoding() : undef;
+    $iRequest->send_http_header( $ctype || 'text/html', $cs );
     $iTemplate ? $iTemplate->flush() : $iRequest->print($body);
     return 1;
 }
