@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007-2008 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2009 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Error.pm 1645 2008-02-06 15:40:18Z hikarin $
+# $Id: Error.pm 1826 2009-04-08 15:23:25Z hikarin $
 #
 
 package Img0ch::Error;
@@ -24,17 +24,19 @@ use strict;
 sub new {
     my ( $iClass, $iObject, $key, $ip_int ) = @_;
     my $class = ref $iObject || '';
-    my ( $iKernel, $bbs, $common );
+    my ( $iKernel, $bbs, $common, $encoding );
 
     if ( $class eq 'Img0ch::BBS' ) {
-        $iKernel = $iObject->get_kernel();
-        $bbs     = $iObject->get_name() || 'test';
-        $common  = $iObject->get_common_repos();
+        $iKernel  = $iObject->get_kernel();
+        $bbs      = $iObject->get_name() || 'test';
+        $common   = $iObject->get_common_repos();
+        $encoding = $iObject->get_encoding();
     }
     elsif ( $class eq 'Img0ch::Kernel' or $class eq 'Img0ch::Maple' ) {
-        $iKernel = $iObject;
-        $bbs     = 'test';
-        $common  = $iKernel->get_repos( $iKernel->get_repos_path('common') );
+        $iKernel  = $iObject;
+        $bbs      = 'test';
+        $common   = $iKernel->get_repos( $iKernel->get_repos_path('common') );
+        $encoding = undef;
     }
     else {
         Img0ch::Kernel->throw_exception(
@@ -48,14 +50,15 @@ sub new {
     my $iRepos = $iKernel->get_repos_nocache($repos_path);
 
     bless {
-        _bbs    => $bbs,
-        __cache => '',
-        __date  => $date,
-        __error => $common,
-        __ip    => $ip_int,
-        _kernel => $iKernel,
-        __key   => ( $key || '0' ),
-        _rs     => $iRepos,
+        _bbs      => $bbs,
+        __cache   => '',
+        __date    => $date,
+        _encoding => $encoding,
+        __error   => $common,
+        __ip      => $ip_int,
+        _kernel   => $iKernel,
+        __key     => ( $key || '0' ),
+        _rs       => $iRepos,
     }, $iClass;
 }
 
@@ -68,13 +71,23 @@ sub get {
 
     my $iKernel = $iError->{_kernel};
     my $iConfig = $iKernel->get_config();
-    my $path    = $iConfig->get('SystemPath') . '/error.txt';
-    my $fh      = $iKernel->get_read_file_handle($path);
+    my $path
+        = $iConfig->get('SystemPath')
+        . '/locale/'
+        . $iKernel->get_locale()
+        . '/error.txt';
+    if ( !-e $path ) {
+        $path = $iConfig->get('SystemPath') . '/locale/ja_jp/error.txt';
+    }
+
+    my $fh = $iKernel->get_read_file_handle($path);
     while ( my $line = <$fh> ) {
         chomp $line;
         my ( $errid, $errmsg ) = ( split '<>', $line )[ 0, 2 ];
         if ( $key eq $errid ) {
             $iError->{__cache} = $key;
+            my $charset = $iError->{_encoding};
+            $errmsg = $iKernel->get_encoded_str( $errmsg, $charset, 'utf8' );
             return $errmsg;
         }
     }
@@ -86,11 +99,13 @@ sub get {
 sub add {
     my ($iError) = @_;
     my $cache = $iError->{__cache};
-    my %stop_to_add = map { ( $_ => 1 ) } 
+    my %stop_to_add = map { ( $_ => 1 ) }
         qw(DENY_POSTING_ASCII_ONLY INVALID_POST POST_WITH_NGWORD TOO_LONG_MESSAGE);
 
-    if ($cache and !exists $stop_to_add{$cache} 
-        and my $ip_int = $iError->{__ip} ) {
+    if (    $cache
+        and !exists $stop_to_add{$cache}
+        and my $ip_int = $iError->{__ip} )
+    {
         my $iRepos = $iError->{_rs};
         my $bbs    = $iError->{_bbs};
         my $key    = $iError->{__key};
