@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2009 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Pool.pm 1303 2007-10-06 13:29:20Z hikarin $
+# $Id: Pool.pm 1826 2009-04-08 15:23:25Z hikarin $
 #
 
 package Zeromin::Pool;
@@ -188,7 +188,7 @@ sub to_array { $_[0]->{__pool_subject}->to_array() }
 sub to_array_with_page {
     my ( $zPool, $item_per_page, $offset ) = @_;
 
-    require Data::Page;
+    defined $Data::Page::VERSION or require Data::Page;
     my $entries = $zPool->to_array();
     my $page = Data::Page->new( scalar @$entries, $item_per_page, $offset );
     return ( [ $page->splice($entries) ], $page );
