@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: icon.pm 1228 2007-10-01 13:37:14Z hikarin $
+# $Id: icon.pm 1661 2008-03-09 23:53:39Z hikarin $
 #
 
 package Zeromin2::App::icon;
@@ -35,14 +35,14 @@ sub load {
 
     require Data::Page;
     my $zIcon   = Zeromin::Icon->new( $zApp->bbs() );
-    my $entries = $zIcon->get_icon_list();
+    my $entries = $zIcon->to_array();
     my $page = Data::Page->new( scalar @$entries, $zApp->page_param('icon') );
     return $zApp->return_value( 0, [ $page->splice($entries) ], $page );
 }
 
 sub save {
     my ($zApp) = @_;
-    $zApp->check_csrf()               or return $zApp->return_value(1);
+    $zApp->check_csrf() or return $zApp->return_value(1);
     $zApp->privilege('can_edit_head') or return $zApp->return_value(1);
 
     my $iRequest    = $zApp->request();
@@ -107,7 +107,7 @@ sub edit_form {
 
 sub remove {
     my ($zApp) = @_;
-    $zApp->check_csrf()               or return $zApp->return_value(1);
+    $zApp->check_csrf() or return $zApp->return_value(1);
     $zApp->privilege('can_edit_head') or return $zApp->return_value(1);
 
     my @param = $zApp->request()->param('icon');
@@ -132,7 +132,7 @@ sub remove {
 
 sub search {
     my ($zApp) = @_;
-    $zApp->check_csrf()               or return $zApp->return_value(1);
+    $zApp->check_csrf() or return $zApp->return_value(1);
     $zApp->privilege('can_edit_head') or return $zApp->return_value(1);
 
     my $zIcon   = Zeromin::Icon->new( $zApp->bbs() );
