@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: log.pm 1481 2007-10-24 14:13:30Z hikarin $
+# $Id: log.pm 1865 2009-09-13 13:38:42Z hikarin $
 #
 
 package Zeromin2::App::log;
@@ -33,9 +33,10 @@ sub load_error {
     my ( $day, $month, $year ) = _parse_date( $iRequest, $date );
 
     require Zeromin::Log::Error;
-    my $zLogErr = Zeromin::Log::Error->new( $zApp->bbs() || $zApp->kernel() );
-    my $by      = $iRequest->param('by');
-    my $key     = $iRequest->param('key');
+    my $iBBS      = $zApp->bbs();
+    my $zLogErr   = Zeromin::Log::Error->new( $iBBS || $zApp->kernel() );
+    my $by        = $iRequest->param('by');
+    my $key       = $iRequest->param('key');
     my $page_name = 'log_error';
     $zLogErr->load();
 
@@ -65,6 +66,17 @@ sub load_error {
         _get_template_tag_by_day( $template_tag, $year, $month, $day );
     }
 
+    if ($iBBS) {
+        my $iKernel  = $iBBS->get_kernel();
+        my $iSubject = $iBBS->get_subject_instance();
+        my $encoding = $iKernel->get_encoding(1);
+        for my $log (@$content) {
+            my $subject = $iSubject->get( $log->{key} )->[0];
+            $log->{subject}
+                = $iKernel->get_encoded_str( $subject, 'utf8', $encoding );
+        }
+    }
+
     _format_date( $content, 'date' );
     $zApp->add_template_param(
         {   %$template_tag,
@@ -251,7 +263,7 @@ sub lookup {
 
     my $ret = {};
     my $host = gethostbyaddr( pack( 'C*', @ipaddr ), 2 ) || $ip;
-    for my $dnsbl ( 'rbl', 'bbx', 'bbq', 'dsbl' ) {
+    for my $dnsbl ( 'bbx', 'bbq', 'livedoor' ) {
         $ret->{ Img0ch::Plugin::Module::DNSBL->get_hostname($dnsbl) }
             = Img0ch::Plugin::Module::DNSBL->is_in_dnsbl( $dnsbl, undef,
             $ip );
